@@ -1,8 +1,8 @@
 package Class::props ;
-$VERSION = 1.12 ;
+$VERSION = 1.2 ;
 
 use base 'Base::OOTools' ;
-
+   
 1 ;
 
 __END__
@@ -11,9 +11,9 @@ __END__
 
 Class::props - Pragma to implement lvalue accessors with options
 
-=head1 VERSION 1.12
+=head1 VERSION 1.2
 
-Included in OOTools 1.12 distribution. The distribution includes:
+Included in OOTools 1.2 distribution. The distribution includes:
 
 =over
 
@@ -51,7 +51,7 @@ Pragma to implement lvalue accessors with options
     
     # a group of properties with common full options
     use Class::props { name       => \@other_prop_names,   # array ref
-                       default    => 'something' ,
+                       rt_default => sub{$_[0]->other_default} ,
                        validation => sub{ /\w+/ }
                        protected  => 1
                      } ;
@@ -63,7 +63,7 @@ Pragma to implement lvalue accessors with options
                        default    => 10
                      } ,
                      { name       => \@other_prop_names,
-                       default    => 'something' ,
+                       rt_default => sub{$_[0]->other_default} ,
                        validation => sub{ /\w+/ }
                        protected  => 1
                      } ;
@@ -76,15 +76,17 @@ Pragma to implement lvalue accessors with options
     $object->digits    = '123';
     MyClass->digits    = '123';  # same thing
     
-    $object->digits('123');
+    $object->digits('123');      # old way supported
     
-    my $d = $object->digits;  # $d == 123
+    my $d = $object->digits;     # $d == 123
+    $d = $MyClass::digits        # $d == 123
     
-    undef $object->digits     # $object->digits == 10 (default)
+    undef $object->digits        # $object->digits == 10 (default)
     
-    # This would croak
+    # These would croak
     $object->digits    = "xyz";
-
+    MyClass->digits    = "xyz";
+    $MyClass::digits   = "xyz";
 
 =head1 DESCRIPTION
 
@@ -92,6 +94,8 @@ This pragma easily implements lvalue accessor methods for the properties of your
 
 You can completely avoid to write the accessor by just declaring the names and eventually the default value, validation code and other option of your properties.
 
+The accessor method creates a scalar in the class that implements it (e.g. $ImplementingClass::property_name) and ties it to the options you set, so even if you access the scalar without using the accessor, the options will have effect.
+
 =head2 Class properties vs Object properties
 
 The main difference between C<Object::props> and C<Class::props> is that the first pragma creates instance properties related with the object and stored in $object->{property}, while the second pragma creates class properties related with the class and stored in $Class::property.
@@ -161,7 +165,7 @@ From the directory where this file is located, type:
 
 =item name
 
-The name of the property is used as the identifier to create the accessor method, and as the key of the blessed object hash.
+The name of the property is used as the identifier to create the accessor method, and the scalar that contains it.
 
 Given 'my_prop' as the class property name:
 
@@ -181,15 +185,16 @@ You can group properties that have the same set of option by passing a reference
 
 =item default
 
-The property will be initially set to the I<default value>.  You can reset a property to its default value by assigning it the undef value.
+Use this option to set a I<default value>. If any C<validation> option is set, then the I<default value> is validated as well.
+You can reset a property to its default value by assigning it the undef value.
 
-    # this will reset the property to its default
-    MyClass->my_prop = undef ;
-    
-    # this works as well
-    undef MyClass->my_prop ;
+B<Note>:  C<default> and  C<rt_default> are incompatible options: the module will croak if you try to use both for the same property.
 
-If any C<validation> option is set, then the I<default value> is validated at compile time. If no C<default> option is set, then the property will return the undef value and will bypass the C<validation> sub.
+=item rt_default
+
+Almost the same as the C<default> option, but it accepts a code references that will be executed at run-time and should return the default value ('rt' stands for 'run time'). The referenced code will receive the same C<@_> parameters that the property accessor method recieves.
+
+B<Note>:  C<default> and  C<rt_default> are incompatible options: the module will croak if you try to use both for the same property.
 
 =item validation
 
@@ -210,7 +215,7 @@ In the validation code, the object or class is passed in C<$_[0]> and the value
     MyClass->web_color = 'dark gray'
     
     # when used
-    MyClass->uppercase_it = 'abc' # real value will be 'ABC'
+    MyClass->uppercase_it = 'abc' # actual value will be 'ABC'
 
 The validation code should return true on success and false on failure. Croak explicitly if you don't like the default error message.
 
@@ -218,7 +223,7 @@ The validation code should return true on success and false on failure. Croak ex
 
 Set this option to a true value and the property will be turned I<read-only> when used from outside its class or sub-classes. This allows you to normally read and set the property from your class but it will croak if your user tries to set it.
 
-You can however force the protection and set the property from outside the class that implements it by setting $MyClass::force to a true value. (Substitute 'MyClass' with the actual name of the class).
+You can however force the protection and set the property from outside the class that implements it by setting $Base::OOTools::force to a true value.
 
 =back
 
@@ -243,10 +248,6 @@ This code is provided on an "As Is'' basis, without warranty, expressed or impli
 The copyright notice must remain fully intact at all times. Use of this software or its output, constitutes acceptance of these terms.
 
 
-=head1 BUGS
-
-None known, but the module is not completely tested.
-
 =head1 CREDITS
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
